Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2380)

Unified Diff: appengine/swarming/server/task_request.py

Issue 2983203002: config_service: make UI adjustable for mobile (Closed)
Patch Set: config_service: prompt user to sign in when appropriate. Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: appengine/swarming/server/task_request.py
diff --git a/appengine/swarming/server/task_request.py b/appengine/swarming/server/task_request.py
index 063fc2645531e0582db07c00d31f2dcc2e577fdb..177d37afedab8410226c424c52a0673900f3e1e4 100644
--- a/appengine/swarming/server/task_request.py
+++ b/appengine/swarming/server/task_request.py
@@ -75,8 +75,8 @@ import cipd
MAXIMUM_PRIORITY = 255
-# One day in seconds. Add 10s to account for small jitter.
-_ONE_DAY_SECS = 24*60*60 + 10
+# Three days in seconds. Add 10s to account for small jitter.
+_THREE_DAY_SECS = 3*24*60*60 + 10
# Seven day in seconds. Add 10s to account for small jitter.
@@ -227,10 +227,10 @@ def _validate_task_run_id(_prop, value):
def _validate_timeout(prop, value):
"""Validates timeouts in seconds in TaskProperties."""
- if value and not (_MIN_TIMEOUT_SECS <= value <= _ONE_DAY_SECS):
+ if value and not (_MIN_TIMEOUT_SECS <= value <= _THREE_DAY_SECS):
# pylint: disable=W0212
raise datastore_errors.BadValueError(
- '%s (%ds) must be 0 or between %ds and one day' %
+ '%s (%ds) must be 0 or between %ds and three days' %
(prop._name, value, _MIN_TIMEOUT_SECS))
@@ -610,9 +610,9 @@ class TaskProperties(ndb.Model):
'an idempotent task cannot have unpinned packages; '
'use tags or instance IDs as package versions')
- if len(self.outputs) > 2048:
+ if len(self.outputs) > 4096:
raise datastore_errors.BadValueError(
- 'Up to 2048 outputs can be listed for a task')
+ 'Up to 4096 outputs can be listed for a task')
class TaskRequest(ndb.Model):
« no previous file with comments | « appengine/config_service/ui/test/config-ui/config-set_test.html ('k') | appengine/swarming/server/task_request_test.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698